==> jmb.core-0.7.5.tar.gz: jmb.core-0.7.5/jmb/core/conf/docs.py <==
# coding: utf-8
"""
Documentation
=============


Documentation is written with Sphinx...

"""


def get_jumbo_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":" 
    return ("Jumbo", {
        'sub' : [
            ('Framework', {'ref' : '%sindex' % app_label}),
            ( '--', ''),
            ('Buildout', {'ref' : '%sbuildout-env' % app_label}),
            ('Utils', {'ref' : '%sbuildout-utilities' % app_label}),
            ('Troubleshooting', {'ref' : '%stroubleshooting' % app_label}),
            ( '--', ''),
            ('Writing Documentation', {'ref' : '%suse-sphinx' % app_label}),
        ]
    })


def get_packages_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":" 
    return ("Packages", {
        'sub' : [
            ('jmb.core', {'href' : 'http://docs.thux.it/jmb.fax', 'static':True}),
            ( '--', ''),
            ('jmb.async', {'href' : 'http://docs.thux.it/jmb.async', 'static':True}),
            ('jmb.fax', {'href' : 'http://docs.thux.it/jmb.fax', 'static':True}),
            ('jmb.ticket', {'href' : 'http://docs.thux.it/jmb.ticket', 'static':True}),
#            ('jmb.news', {'href' : 'http://docs.thux.it/jmb.news', 'static':True}),
            ('jmb.webposte', {'href' : 'http://docs.thux.it/jmb.webposte', 'static':True}),
            ('jmb.newsletter', {'href' : 'http://docs.thux.it/jmb.newsletter', 'static':True}),
            ( '--', ''),
            ('poste-online', {'href' : 'http://docs.thux.it/poste-online', 'static':True}),
        ]
    })

==> jmb.core-0.7.7.tar.gz: jmb.core-0.7.7/jmb/core/conf/docs.py <==
# coding: utf-8
"""
Documentation
=============


Documentation is written with Sphinx...

"""


def get_jumbo_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":" 
    return ("Jumbo", {
        'sub' : [
            ('Framework', {'ref' : '%sindex' % app_label}),
            ( '--', ''),
            ('Buildout', {'ref' : '%sbuildout-env' % app_label}),
            ('Utils', {'ref' : '%sbuildout-utilities' % app_label}),
            ('Troubleshooting', {'ref' : '%stroubleshooting' % app_label}),
            ( '--', ''),
            ('Writing Documentation', {'ref' : '%suse-sphinx' % app_label}),
        ]
    })


def get_packages_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":" 
    return ("Packages", {
        'sub' : [
            ('jmb.core', {'href' : 'http://docs.thux.it/jmb.core', 'static':True}),
            ('jmb.jadmin', {'href' : 'http://docs.thux.it/jmb.jadmin', 'static':True}),
            ('jmb.filters', {'href' : 'http://docs.thux.it/jmb.filters', 'static':True}),
            ( '--', ''),
            ('jmb.async', {'href' : 'http://docs.thux.it/jmb.async', 'static':True}),
            ('jmb.fax', {'href' : 'http://docs.thux.it/jmb.fax', 'static':True}),
            ('jmb.ticket', {'href' : 'http://docs.thux.it/jmb.ticket', 'static':True}),
#            ('jmb.news', {'href' : 'http://docs.thux.it/jmb.news', 'static':True}),
            ('jmb.webposte', {'href' : 'http://docs.thux.it/jmb.webposte', 'static':True}),
            ('jmb.newsletter', {'href' : 'http://docs.thux.it/jmb.newsletter', 'static':True}),
            ( '--', ''),
            ('poste-online', {'href' : 'http://docs.thux.it/poste-online', 'static':True}),
        ]
    })
